@@ -303,8 +303,6 @@ def complex_filter_calculator(smartquery, driver):
 
 
 def smartner(nl, token, workspace, datasets, language="en-US"):
-    if datasets is None:
-        datasets = []
 
     headers = {
         "Content-Type": "application/json"
