@@ -19,35 +19,30 @@ with open(yaml_path, 'r') as file:
 # SmartJoin
 def smart_join(tables):
 
-    if bool(tables):
+    headers = {
+        "Content-Type": "application/json"
+    }
 
-        headers = {
-            "Content-Type": "application/json"
-        }
+    data = {
+        "tables": tables
+    }
 
-        data = {
-            "tables": tables
-        }
+    s = requests.Session()
+    s.keep_alive = False
+    retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+    s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        s = requests.Session()
-        s.keep_alive = False
-        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
-        s.mount('https://', HTTPAdapter(max_retries=retries))
+    url = url_list['BASE_URL_SMARTJOIN_DEV'] + "/get_joins"
 
-        url = url_list['BASE_URL_SMARTJOIN_DEV'] + "/get_joins"
+    r = s.post(url=url, headers=headers, json=data)
+    r.raise_for_status()
 
-        r = s.post(url=url, headers=headers, json=data)
-        r.raise_for_status()
-
-        try:
-            response = r.json()['joins']
-            return response
-        except Exception as e:
-            logging.error(str(e))
-            print(e)
-            return None
-    else:
-        print("The input is empty!")
+    try:
+        response = r.json()
+        return response
+    except Exception as e:
+        logging.error(str(e))
+        print(e)
         return None
 
 
@@ -129,6 +124,40 @@ def smart_substitution(sentence, language="en"):
         print("No substitution needed. Empty string or <mask> not in input sentence.")
 
 
+def smart_title(smartquery, metadata, lang="en-US"):
+
+    if "en" not in lang.lower() and "it" not in lang.lower():
+        lang = "en-US"
+        print("Input language wrong. Using: English")
+
+    # Google Pod
+    headers = {
+        "Content-Type": "application/json"
+    }
+
+    s = requests.Session()
+    s.keep_alive = False
+    retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+    s.mount('https://', HTTPAdapter(max_retries=retries))
+
+    url = url_list['BASE_URL_SMARTJOIN_DEV'] + "/create_title"
+
+    data = {
+        "smartquery": smartquery,
+        "metadata": metadata,
+        "language": lang
+    }
+
+    r = s.post(url=url, headers=headers, json=data)
+    r.raise_for_status()
+
+    try:
+        response = r.json()['title']
+        return response
+    except Exception as e:
+        logging.error(str(e))
+
+
 # SmartOpenData
 def smart_opendata(sentence, language="en", show_header=False, dataset_score_dict=None, boost_columns=False,
                 boost_name_score=False, use_domains=True, store_df=True):
